==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/IncludedPathArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.IncludedPathArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The paths that are included in indexing
 * @property indexes List of indexes for this path
 * @property path The path for which the indexing behavior applies to. Index paths typically start with root and end with wildcard (/path/*)
 * */
 */
public data class IncludedPathArgs(
    public val indexes: Output<List<IndexesArgs>>? = null,
    public val path: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.IncludedPathArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.IncludedPathArgs =
        com.pulumi.azurenative.documentdb.inputs.IncludedPathArgs.builder()
            .indexes(
                indexes?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .path(path?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IncludedPathArgs].
 */
@PulumiTagMarker
public class IncludedPathArgsBuilder internal constructor() {
    private var indexes: Output<List<IndexesArgs>>? = null

    private var path: Output<String>? = null

    /**
     * @param value List of indexes for this path
     */
    @JvmName("msnlabmwntfqlibu")
    public suspend fun indexes(`value`: Output<List<IndexesArgs>>) {
        this.indexes = value
    }

    @JvmName("xcsxsuciylbqtuin")
    public suspend fun indexes(vararg values: Output<IndexesArgs>) {
        this.indexes = Output.all(values.asList())
    }

    /**
     * @param values List of indexes for this path
     */
    @JvmName("khiiemxohnkulgwi")
    public suspend fun indexes(values: List<Output<IndexesArgs>>) {
        this.indexes = Output.all(values)
    }

    /**
     * @param value The path for which the indexing behavior applies to. Index paths typically start with root and end with wildcard (/path/*)
     * */
     */
    @JvmName("cwaommqnhbckaxbr")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value List of indexes for this path
     */
    @JvmName("exihibceasadygqx")
    public suspend fun indexes(`value`: List<IndexesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.indexes = mapped
    }

    /**
     * @param argument List of indexes for this path
     */
    @JvmName("tenkwirkcsnuvawf")
    public suspend fun indexes(argument: List<suspend IndexesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { IndexesArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.indexes = mapped
    }

    /**
     * @param argument List of indexes for this path
     */
    @JvmName("piwmehdyabrkpfcv")
    public suspend fun indexes(vararg argument: suspend IndexesArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { IndexesArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.indexes = mapped
    }

    /**
     * @param argument List of indexes for this path
     */
    @JvmName("gxjdwbxmxpkeverd")
    public suspend fun indexes(argument: suspend IndexesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IndexesArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.indexes = mapped
    }

    /**
     * @param values List of indexes for this path
     */
    @JvmName("wdntcejmkkgqsgil")
    public suspend fun indexes(vararg values: IndexesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.indexes = mapped
    }

    /**
     * @param value The path for which the indexing behavior applies to. Index paths typically start with root and end with wildcard (/path/*)
     * */
     */
    @JvmName("iipvusaxfukkhugs")
    public suspend fun path(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.path = mapped
    }

    internal fun build(): IncludedPathArgs = IncludedPathArgs(
        indexes = indexes,
        path = path,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/IncludedPathArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.IncludedPathArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The paths that are included in indexing
 * @property indexes List of indexes for this path
 * @property path The path for which the indexing behavior applies to. Index paths typically start with root and end with wildcard (/path/*)
 * */
 */
public data class IncludedPathArgs(
    public val indexes: Output<List<IndexesArgs>>? = null,
    public val path: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.IncludedPathArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.IncludedPathArgs =
        com.pulumi.azurenative.documentdb.inputs.IncludedPathArgs.builder()
            .indexes(
                indexes?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .path(path?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IncludedPathArgs].
 */
@PulumiTagMarker
public class IncludedPathArgsBuilder internal constructor() {
    private var indexes: Output<List<IndexesArgs>>? = null

    private var path: Output<String>? = null

    /**
     * @param value List of indexes for this path
     */
    @JvmName("sehqxojoqwpavphc")
    public suspend fun indexes(`value`: Output<List<IndexesArgs>>) {
        this.indexes = value
    }

    @JvmName("mtpnteutdhlmbgkv")
    public suspend fun indexes(vararg values: Output<IndexesArgs>) {
        this.indexes = Output.all(values.asList())
    }

    /**
     * @param values List of indexes for this path
     */
    @JvmName("tdxcnxnonruoxwxc")
    public suspend fun indexes(values: List<Output<IndexesArgs>>) {
        this.indexes = Output.all(values)
    }

    /**
     * @param value The path for which the indexing behavior applies to. Index paths typically start with root and end with wildcard (/path/*)
     * */
     */
    @JvmName("mjsbxuojwibyfdhq")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value List of indexes for this path
     */
    @JvmName("tmbwthfloiqhxmkx")
    public suspend fun indexes(`value`: List<IndexesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.indexes = mapped
    }

    /**
     * @param argument List of indexes for this path
     */
    @JvmName("oxsnkjglkniflhts")
    public suspend fun indexes(argument: List<suspend IndexesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { IndexesArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.indexes = mapped
    }

    /**
     * @param argument List of indexes for this path
     */
    @JvmName("jcdabocqmisnblce")
    public suspend fun indexes(vararg argument: suspend IndexesArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { IndexesArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.indexes = mapped
    }

    /**
     * @param argument List of indexes for this path
     */
    @JvmName("koftxkudxaqfisfl")
    public suspend fun indexes(argument: suspend IndexesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IndexesArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.indexes = mapped
    }

    /**
     * @param values List of indexes for this path
     */
    @JvmName("oxpoofiywpyvitfn")
    public suspend fun indexes(vararg values: IndexesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.indexes = mapped
    }

    /**
     * @param value The path for which the indexing behavior applies to. Index paths typically start with root and end with wildcard (/path/*)
     * */
     */
    @JvmName("uivrrjfsagomqjqd")
    public suspend fun path(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.path = mapped
    }

    internal fun build(): IncludedPathArgs = IncludedPathArgs(
        indexes = indexes,
        path = path,
    )
}
